record.SaxToDomHandler

|  | ## Cheshire3 Object Model: Class SaxToDomHandler

Module record :: Class SaxToDomHandler

## Class SaxToDomHandler
source code

Instance Methods

initState(self)
startElement(self, name, attribs={})
endElement(self, foo)
characters(self, text, zero=0, length=0)
startElementNS(self, name, qname, attribs)
endElementNS(self, name, qname)
startPrefixMapping(self, pref, uri)
getRootNode(self)

Class Variables

nodeStack |
document |
currText |

Method Details

### initState(self) | source code

### startElement(self, name, attribs={}) | source code

### endElement(self, foo) | source code

### characters(self, text, zero=0, length=0) | source code

### startElementNS(self, name, qname, attribs) | source code

### endElementNS(self, name, qname) | source code

### startPrefixMapping(self, pref, uri) | source code

### getRootNode(self) | source code

Class Variable Details

    ### nodeStack Value:
        []

    ### document Value:
        None

    ### currText Value:
        ''